**DigiDuck: Ducky Script to Digispark**
=======================================
This is a simple program that converts Ducky Script for Hak5 USB Rubber Duckys into code executable by a Digispark.
As of yet there is no support for the BREAK key, but all other keys work fine.
Additionally, you will need to escape characters in your printed strings by hand currently.

Written by `Uslurper <https://github.com/uslurper>`_.

Usage: digiduck [source.txt] [dest.txt]

It's that simple.
